@@ -2,7 +2,7 @@ import numpy as np
 from dyntapy.dta.core.demand import InternalDynamicDemand
 from dyntapy.dta.core.network_loading.link_models.i_ltm import i_ltm
 from dyntapy.dta.core.network_loading.link_models.i_ltm_setup import i_ltm_aon_setup
-from dyntapy.dta.core.network_loading.link_models.utilities import cvn_to_flows, _debug_plot, cvn_to_travel_times
+from dyntapy.dta.core.network_loading.link_models.utilities import cvn_to_flows, cvn_to_travel_times
 from dyntapy.dta.core.route_choice.aon_setup import incremental_loading, get_aon_route_choice
 from dyntapy.dta.core.supply import Network
 from dyntapy.dta.core.time import SimulationTime
