@@ -25,7 +25,7 @@ from shapely.geometry import LineString
 from dyntapy.utilities import __create_green_to_red_cm
 import osmnx as ox
 from pyproj import CRS
-from dyntapy.__init__ import results_folder, current_network
+from dyntapy.__init__ import results_folder
 from dyntapy.settings import dynamic_parameters
 from dyntapy.dta.core.time import SimulationTime
 from dyntapy.network_data import relabel_graph
@@ -216,7 +216,6 @@ def show_dynamic_network(g: nx.DiGraph, time: SimulationTime, flows=None, link_k
                       plot_width=plot_size,
                       aspect_ratio=1, toolbar_location='below')
         tmp = g
-    plot.title.text = title
     title = _check_title(title, g, 'assignment ')
     plot.title.text = title
 
@@ -359,6 +358,7 @@ def show_demand(g, title=None, plot_size=default_plot_size, notebook=False, toy_
     else:
         output_file(results_folder + f'/{title}.html')
     if not toy_network:
+        g.graph["crs"] = 'epsg:4326'
         tmp = ox.project_graph(g, CRS.from_user_input(3857))
         plot = figure(plot_height=plot_size,
                       plot_width=plot_size, x_axis_type="mercator", y_axis_type="mercator",
